package util
import "go.mau.fi/util"
Index ¶
Constants ¶
const Version = "v0.8.6"
Functions ¶
func VersionArray ¶
func VersionArray() [3]uint
Source Files ¶
util.go
Directories ¶
| Path | Synopsis |
|---|---|
| base58 | Package base58 provides an API for working with modified base58 and Base58Check encodings. |
| configupgrade | |
| confusable | Package confusable implements confusable detection according to UTS #39. |
| curl | |
| dbutil | |
| dbutil/litestream | |
| emojirunes | |
| exbytes | |
| exerrors | |
| exfmt | |
| exgjson | |
| exhttp | |
| exmime | |
| exslices | |
| exstrings | |
| exsync | |
| exzerolog | |
| fallocate | Package fallocate provides a unified interface for preallocating space for a file. |
| ffmpeg | |
| glob | Package glob implements very simple glob pattern matching used in various parts of the Matrix spec, such as push rules and moderation policy lists. |
| gnuzip | |
| jsonbytes | |
| jsontime | |
| lottie | |
| pblite | |
| progress | Package progress provides wrappers for io.Writer and io.Reader that report the progress of the read or write operation via a callback. |
| ptr | |
| random | |
| requestlog | |
| retryafter | Package retryafter contains a utility function for parsing the Retry-After HTTP header. |
| shlex | Package shlex implements a simple lexer which splits input in to tokens using shell-style rules for quoting and commenting. |
| unicodeurls | Package unicodeurls contains URLs for Unicode data files. |
| variationselector | Package variationselector provides utility functions for adding and removing emoji variation selectors (16) that matches the suggestions in the Matrix spec. |
- Version
- v0.8.6 (latest)
- Published
- Mar 16, 2025
- Platform
- linux/amd64
- Last checked
- 1 year ago –
Tools for package owners.